@@ -10,9 +10,10 @@
 
 from .parser import parse
 from .wrapper import Wrapper, IterWrapper
+from .__version__ import __version__
 import logging
 
-__all__ = ['parse', 'Wrapper', 'IterWrapper']
+__all__ = ['parse', 'Wrapper', 'IterWrapper', '__version__']
 
 log = logging.getLogger(__name__)
 log.addHandler(logging.NullHandler())
